package java.awt.image;

import sun.java2d.cmm.ProfileDeferralMgr;
import java.awt.geom.Point2D;
import java.awt.Point;
import java.awt.geom.Rectangle2D;
import sun.java2d.cmm.PCMM;
import sun.java2d.cmm.CMSManager;
import java.awt.Graphics2D;
import java.awt.color.ICC_ColorSpace;
import java.awt.RenderingHints;
import sun.java2d.cmm.ColorTransform;
import java.awt.color.ColorSpace;
import java.awt.color.ICC_Profile;

public class ColorConvertOp implements BufferedImageOp, RasterOp
{
    ICC_Profile[] profileList;
    ColorSpace[] CSList;
    ColorTransform thisTransform;
    ColorTransform thisRasterTransform;
    ICC_Profile thisSrcProfile;
    ICC_Profile thisDestProfile;
    RenderingHints hints;
    boolean gotProfiles;
    float[] srcMinVals;
    float[] srcMaxVals;
    float[] dstMinVals;
    float[] dstMaxVals;
    
    public ColorConvertOp(RenderingHints hints) {
        this.profileList = new ICC_Profile[0];
        this.hints = hints;
    }
    
    public ColorConvertOp(ColorSpace colorSpace, RenderingHints hints) {
        if (colorSpace == null) {
            throw new NullPointerException("ColorSpace cannot be null");
        }
        if ((colorSpace instanceof ICC_ColorSpace)) {
            (this.profileList = new ICC_Profile[1])[0] = ((ICC_ColorSpace)colorSpace).getProfile();
        }
        else {
            (this.CSList = new ColorSpace[1])[0] = colorSpace;
        }
        this.hints = hints;
        return;
    }
    
    public ColorConvertOp(ColorSpace colorSpace, ColorSpace colorSpace2, RenderingHints hints) {
        if (colorSpace == null || colorSpace2 == null) {
            throw new NullPointerException("ColorSpaces cannot be null");
        }
        if (colorSpace instanceof ICC_ColorSpace && colorSpace2 instanceof ICC_ColorSpace) {
            (this.profileList = new ICC_Profile[2])[0] = ((ICC_ColorSpace)colorSpace).getProfile();
            this.profileList[1] = ((ICC_ColorSpace)colorSpace2).getProfile();
            this.getMinMaxValsFromColorSpaces(colorSpace, colorSpace2);
        }
        else {
            (this.CSList = new ColorSpace[2])[0] = colorSpace;
            this.CSList[1] = colorSpace2;
        }
        this.hints = hints;
        return;
    }
    
    public ColorConvertOp(ICC_Profile[] array, RenderingHints hints) {
        if (array == null) {
            throw new NullPointerException("Profiles cannot be null");
        }
        this.gotProfiles = true;
        this.profileList = new ICC_Profile[array.length];
        for (int i = 0; i < array.length; ++i) {
            this.profileList[i] = array[i];
        }
        this.hints = hints;
        return;
    }
    
    public final ICC_Profile[] getICC_Profiles() {
        if (this.gotProfiles) {
            ICC_Profile[] array = new ICC_Profile[this.profileList.length];
            for (int i = 0; i < this.profileList.length; ++i) {
                array[i] = this.profileList[i];
            }
            return array;
        }
        return null;
    }
    
    @Override
    public final BufferedImage filter(BufferedImage convertToIntDiscrete, BufferedImage bufferedImage) {
        BufferedImage bufferedImage2 = null;
        if ((convertToIntDiscrete.getColorModel() instanceof IndexColorModel)) {
            convertToIntDiscrete = ((IndexColorModel)convertToIntDiscrete.getColorModel()).convertToIntDiscrete(convertToIntDiscrete.getRaster(), true);
        }
        ColorSpace colorSpace = convertToIntDiscrete.getColorModel().getColorSpace();
        ColorSpace colorSpace2;
        if (bufferedImage != null) {
            if ((bufferedImage.getColorModel() instanceof IndexColorModel)) {
                bufferedImage2 = bufferedImage;
                bufferedImage = null;
                colorSpace2 = null;
            }
            else {
                colorSpace2 = bufferedImage.getColorModel().getColorSpace();
            }
        }
        else {
            colorSpace2 = null;
        }
        if (this.CSList != null || !(colorSpace instanceof ICC_ColorSpace) || (bufferedImage != null && !(colorSpace2 instanceof ICC_ColorSpace))) {
            bufferedImage = this.nonICCBIFilter(convertToIntDiscrete, colorSpace, bufferedImage, colorSpace2);
        }
        else {
            bufferedImage = this.ICCBIFilter(convertToIntDiscrete, colorSpace, bufferedImage, colorSpace2);
        }
        if (bufferedImage2 != null) {
            Graphics2D graphics = bufferedImage2.createGraphics();
            try {
                graphics.drawImage(bufferedImage, 0, 0, null);
            }
            finally {
                graphics.dispose();
            }
            return bufferedImage2;
        }
        return bufferedImage;
    }
    
    private final BufferedImage ICCBIFilter(BufferedImage bufferedImage, ColorSpace colorSpace, BufferedImage compatibleDestImage, ColorSpace colorSpace2) {
        int length = this.profileList.length;
        ICC_Profile profile = ((ICC_ColorSpace)colorSpace).getProfile();
        ICC_Profile profile2;
        if (compatibleDestImage == null) {
            if (length == 0) {
                throw new IllegalArgumentException("Destination ColorSpace is undefined");
            }
            profile2 = this.profileList[length - 1];
            compatibleDestImage = this.createCompatibleDestImage(bufferedImage, null);
        }
        else {
            if (bufferedImage.getHeight() != compatibleDestImage.getHeight() || bufferedImage.getWidth() != compatibleDestImage.getWidth()) {
                throw new IllegalArgumentException("Width or height of BufferedImages do not match");
            }
            profile2 = ((ICC_ColorSpace)colorSpace2).getProfile();
        }
        if (profile == profile2) {
            boolean n = true;
            int i = 0;
            while (i < length) {
                if (profile != this.profileList[i]) {
                    n = false;
                    break;
                }
                ++i;
            }
            if (!(n == 0)) {
                Graphics2D graphics = compatibleDestImage.createGraphics();
                try {
                    graphics.drawImage(bufferedImage, 0, 0, null);
                }
                finally {
                    graphics.dispose();
                }
                return compatibleDestImage;
            }
        }
        if (this.thisTransform == null || this.thisSrcProfile != profile || this.thisDestProfile != profile2) {
            this.updateBITransform(profile, profile2);
        }
        this.thisTransform.colorConvert(bufferedImage, compatibleDestImage);
        return compatibleDestImage;
    }
    
    private void updateBITransform(ICC_Profile thisSrcProfile, ICC_Profile thisDestProfile) {
        boolean n = false;
        boolean n2 = false;
        int length = this.profileList.length;
        if (length == 0 || thisSrcProfile != this.profileList[0]) {
            ++length;
            n = true;
        }
        if (length == 0 || thisDestProfile != this.profileList[length - 1] || length < 2) {
            ++length;
            n2 = true;
        }
        ICC_Profile[] array = new ICC_Profile[length];
        int n3 = 0;
        if (!(n == 0)) {
            array[n3++] = thisSrcProfile;
        }
        for (int i = 0; i < length; ++i) {
            array[n3++] = this.profileList[i];
        }
        if (!(n2 == 0)) {
            array[n3] = thisDestProfile;
        }
        ColorTransform[] array2 = new ColorTransform[length];
        int renderingIntent;
        if (array[0].getProfileClass() == 2) {
            renderingIntent = 1;
        }
        else {
            renderingIntent = 0;
        }
        int n4 = 1;
        PCMM module = CMSManager.getModule();
        for (int j = 0; j < length; array2[j] = module.createTransform(array[j], renderingIntent, n4), renderingIntent = this.getRenderingIntent(array[j]), n4 = 4, ++j) {
            if (j == length - 1) {
                n4 = 2;
            }
            else if (n4 == 4 && array[j].getProfileClass() == 5) {
                renderingIntent = 0;
                n4 = 1;
            }
        }
        this.thisTransform = module.createTransform(array2);
        this.thisSrcProfile = thisSrcProfile;
        this.thisDestProfile = thisDestProfile;
    }
    
    @Override
    public final WritableRaster filter(Raster raster, WritableRaster compatibleDestRaster) {
        if (this.CSList != null) {
            return this.nonICCRasterFilter(raster, compatibleDestRaster);
        }
        int length = this.profileList.length;
        if (length < 2) {
            throw new IllegalArgumentException("Source or Destination ColorSpace is undefined");
        }
        if (raster.getNumBands() != this.profileList[0].getNumComponents()) {
            throw new IllegalArgumentException("Numbers of source Raster bands and source color space components do not match");
        }
        if (compatibleDestRaster == null) {
            compatibleDestRaster = this.createCompatibleDestRaster(raster);
        }
        else {
            if (raster.getHeight() != compatibleDestRaster.getHeight() || raster.getWidth() != compatibleDestRaster.getWidth()) {
                throw new IllegalArgumentException("Width or height of Rasters do not match");
            }
            if (compatibleDestRaster.getNumBands() != this.profileList[length - 1].getNumComponents()) {
                throw new IllegalArgumentException("Numbers of destination Raster bands and destination color space components do not match");
            }
        }
        if (this.thisRasterTransform == null) {
            ColorTransform[] array = new ColorTransform[length];
            int renderingIntent;
            if (this.profileList[0].getProfileClass() == 2) {
                renderingIntent = 1;
            }
            else {
                renderingIntent = 0;
            }
            int n = 1;
            PCMM module = CMSManager.getModule();
            for (int i = 0; i < length; array[i] = module.createTransform(this.profileList[i], renderingIntent, n), renderingIntent = this.getRenderingIntent(this.profileList[i]), n = 4, ++i) {
                if (i == length - 1) {
                    n = 2;
                }
                else if (n == 4 && this.profileList[i].getProfileClass() == 5) {
                    renderingIntent = 0;
                    n = 1;
                }
            }
            this.thisRasterTransform = module.createTransform(array);
        }
        int transferType = raster.getTransferType();
        int transferType2 = compatibleDestRaster.getTransferType();
        if (transferType == 4 || transferType == 5 || transferType2 == 4 || transferType2 == 5) {
            if (this.srcMinVals == null) {
                this.getMinMaxValsFromProfiles(this.profileList[0], this.profileList[length - 1]);
            }
            this.thisRasterTransform.colorConvert(raster, compatibleDestRaster, this.srcMinVals, this.srcMaxVals, this.dstMinVals, this.dstMaxVals);
            return compatibleDestRaster;
        }
        else {
            this.thisRasterTransform.colorConvert(raster, compatibleDestRaster);
            return compatibleDestRaster;
        }
    }
    
    @Override
    public final Rectangle2D getBounds2D(BufferedImage bufferedImage) {
        return this.getBounds2D(bufferedImage.getRaster());
    }
    
    @Override
    public final Rectangle2D getBounds2D(Raster raster) {
        return raster.getBounds();
    }
    
    @Override
    public BufferedImage createCompatibleDestImage(BufferedImage bufferedImage, ColorModel colorModel) {
        ColorSpace colorSpace = null;
        if (colorModel == null) {
            if (this.CSList == null) {
                int length = this.profileList.length;
                if (length == 0) {
                    throw new IllegalArgumentException("Destination ColorSpace is undefined");
                }
                colorSpace = new ICC_ColorSpace(this.profileList[length - 1]);
            }
            else {
                colorSpace = this.CSList[this.CSList.length - 1];
            }
        }
        return this.createCompatibleDestImage(bufferedImage, colorModel, colorSpace);
    }
    
    private BufferedImage createCompatibleDestImage(BufferedImage bufferedImage, ColorModel colorModel, ColorSpace colorSpace) {
        if (colorModel == null) {
            ColorModel colorModel2 = bufferedImage.getColorModel();
            int numComponents = colorSpace.getNumComponents();
            int hasAlpha = colorModel2.hasAlpha();
            if (!(hasAlpha == 0)) {
                ++numComponents;
            }
            int[] array = new int[numComponents];
            for (int i = 0; i < numComponents; ++i) {
                array[i] = 8;
            }
            colorModel = new ComponentColorModel(colorSpace, array, (boolean)hasAlpha, colorModel2.isAlphaPremultiplied(), colorModel2.getTransparency(), 0);
        }
        return new BufferedImage(colorModel, colorModel.createCompatibleWritableRaster(bufferedImage.getWidth(), bufferedImage.getHeight()), colorModel.isAlphaPremultiplied(), null);
    }
    
    @Override
    public WritableRaster createCompatibleDestRaster(Raster raster) {
        int n;
        if (this.CSList != null) {
            if (this.CSList.length != 2) {
                throw new IllegalArgumentException("Destination ColorSpace is undefined");
            }
            n = this.CSList[1].getNumComponents();
        }
        else {
            int length = this.profileList.length;
            if (length < 2) {
                throw new IllegalArgumentException("Destination ColorSpace is undefined");
            }
            n = this.profileList[length - 1].getNumComponents();
        }
        return Raster.createInterleavedRaster(0, raster.getWidth(), raster.getHeight(), n, new Point(raster.getMinX(), raster.getMinY()));
    }
    
    @Override
    public final Point2D getPoint2D(Point2D point2D, Point2D point2D2) {
        if (point2D2 == null) {
            point2D2 = new Point2D.Float();
        }
        point2D2.setLocation(point2D.getX(), point2D.getY());
        return point2D2;
    }
    
    private int getRenderingIntent(ICC_Profile icc_Profile) {
        byte[] data = icc_Profile.getData(1751474532);
        int n = 64;
        return (data[n + 2] & 0xFF) << 8 | (data[n + 3] & 0xFF);
    }
    
    @Override
    public final RenderingHints getRenderingHints() {
        return this.hints;
    }
    
    private final BufferedImage nonICCBIFilter(BufferedImage bufferedImage, ColorSpace colorSpace, BufferedImage compatibleDestImage, ColorSpace colorSpace2) {
        int width = bufferedImage.getWidth();
        int height = bufferedImage.getHeight();
        ICC_ColorSpace icc_ColorSpace = (ColorSpace)ColorSpace.getInstance(1001);
        if (compatibleDestImage == null) {
            compatibleDestImage = this.createCompatibleDestImage(bufferedImage, null);
            colorSpace2 = compatibleDestImage.getColorModel().getColorSpace();
        }
        else if (height != compatibleDestImage.getHeight() || width != compatibleDestImage.getWidth()) {
            throw new IllegalArgumentException("Width or height of BufferedImages do not match");
        }
        WritableRaster raster = bufferedImage.getRaster();
        WritableRaster raster2 = compatibleDestImage.getRaster();
        ColorModel colorModel = bufferedImage.getColorModel();
        ColorModel colorModel2 = compatibleDestImage.getColorModel();
        int numColorComponents = colorModel.getNumColorComponents();
        int numColorComponents2 = colorModel2.getNumColorComponents();
        int hasAlpha = colorModel2.hasAlpha();
        int n = colorModel.hasAlpha() && hasAlpha;
        if (this.CSList == null && this.profileList.length != 0) {
            int n2;
            ICC_Profile icc_Profile;
            if (!(colorSpace instanceof ICC_ColorSpace)) {
                n2 = true;
                icc_Profile = icc_ColorSpace.getProfile();
            }
            else {
                n2 = false;
                icc_Profile = ((ICC_ColorSpace)colorSpace).getProfile();
            }
            int n3;
            ICC_Profile icc_Profile2;
            if (!(colorSpace2 instanceof ICC_ColorSpace)) {
                n3 = true;
                icc_Profile2 = icc_ColorSpace.getProfile();
            }
            else {
                n3 = false;
                icc_Profile2 = ((ICC_ColorSpace)colorSpace2).getProfile();
            }
            if (this.thisTransform == null || this.thisSrcProfile != icc_Profile || this.thisDestProfile != icc_Profile2) {
                this.updateBITransform(icc_Profile, icc_Profile2);
            }
            float n4 = 65535.0f;
            int n5;
            if (!(n2 == 0)) {
                n5 = 3;
            }
            else {
                icc_ColorSpace = colorSpace;
                n5 = numColorComponents;
            }
            float[] array3 = new float[n5];
            float[] array4 = new float[n5];
            for (int n6 = 0; n6 < numColorComponents; ++n6) {
                array3[n6] = icc_ColorSpace.getMinValue(n6);
                array4[n6] = n4 / (icc_ColorSpace.getMaxValue(n6) - array3[n6]);
            }
            int n7;
            if (!(n3 == 0)) {
                n7 = 3;
            }
            else {
                icc_ColorSpace = colorSpace2;
                n7 = numColorComponents2;
            }
            float[] array5 = new float[n7];
            float[] array6 = new float[n7];
            for (int n8 = 0; n8 < numColorComponents2; ++n8) {
                array5[n8] = icc_ColorSpace.getMinValue(n8);
                array6[n8] = (icc_ColorSpace.getMaxValue(n8) - array5[n8]) / n4;
            }
            float[] array7;
            if (!(hasAlpha == 0)) {
                array7 = new float[(numColorComponents2 + 1 > 3) ? (numColorComponents2 + 1) : 3];
            }
            else {
                array7 = new float[(numColorComponents2 > 3) ? numColorComponents2 : 3];
            }
            short[] array8 = new short[width * n5];
            short[] array9 = new short[width * n7];
            float[] array10 = null;
            if (!(n == 0)) {
                array10 = new float[width];
            }
            for (int n9 = 0; n9 < height; ++n9) {
                Object dataElements3 = null;
                float[] array11 = null;
                int n10 = 0;
                for (int n11 = 0; n11 < width; ++n11) {
                    dataElements3 = raster.getDataElements(n11, n9, dataElements3);
                    array11 = colorModel.getNormalizedComponents(dataElements3, array11, 0);
                    if (!(n == 0)) {
                        array10[n11] = array11[numColorComponents];
                    }
                    if (!(n2 == 0)) {
                        array11 = colorSpace.toCIEXYZ(array11);
                    }
                    for (int n12 = 0; n12 < n5; ++n12) {
                        array8[n10++] = (short)(int)((array11[n12] - array3[n12]) * array4[n12] + 0.5f);
                    }
                }
                this.thisTransform.colorConvert(array8, array9);
                Object dataElements4 = null;
                int n13 = 0;
                for (int n14 = 0; n14 < width; ++n14) {
                    for (int n15 = 0; n15 < n7; ++n15) {
                        array7[n15] = (float)(array9[n13++] & 0xFFFF) * array6[n15] + array5[n15];
                    }
                    if (!(n3 == 0)) {
                        float[] fromCIEXYZ2 = colorSpace.fromCIEXYZ(array7);
                        for (int n16 = 0; n16 < numColorComponents2; ++n16) {
                            array7[n16] = fromCIEXYZ2[n16];
                        }
                    }
                    if (!(n == 0)) {
                        array7[numColorComponents2] = array10[n14];
                    }
                    else if (!(hasAlpha == 0)) {
                        array7[numColorComponents2] = 1.0f;
                    }
                    dataElements4 = colorModel2.getDataElements(array7, 0, dataElements4);
                    raster2.setDataElements(n14, n9, dataElements4);
                }
            }
            return compatibleDestImage;
        }
        else {
            int length;
            if (this.CSList == null) {
                length = 0;
            }
            else {
                length = this.CSList.length;
            }
            float[] array;
            if (!(hasAlpha == 0)) {
                array = new float[numColorComponents2 + 1];
            }
            else {
                array = new float[numColorComponents2];
            }
            Object dataElements = null;
            Object dataElements2 = null;
            float[] normalizedComponents = null;
            for (int i = 0; i < height; ++i) {
                for (int j = 0; j < width; ++j) {
                    dataElements = raster.getDataElements(j, i, dataElements);
                    normalizedComponents = colorModel.getNormalizedComponents(dataElements, normalizedComponents, 0);
                    float[] array2 = colorSpace.toCIEXYZ(normalizedComponents);
                    for (int k = 0; k < length; ++k) {
                        array2 = this.CSList[k].toCIEXYZ(this.CSList[k].fromCIEXYZ(array2));
                    }
                    float[] fromCIEXYZ = colorSpace2.fromCIEXYZ(array2);
                    for (int l = 0; l < numColorComponents2; ++l) {
                        array[l] = fromCIEXYZ[l];
                    }
                    if (!(n == 0)) {
                        array[numColorComponents2] = normalizedComponents[numColorComponents];
                    }
                    else if (!(hasAlpha == 0)) {
                        array[numColorComponents2] = 1.0f;
                    }
                    dataElements2 = colorModel2.getDataElements(array, 0, dataElements2);
                    raster2.setDataElements(j, i, dataElements2);
                }
            }
            return compatibleDestImage;
        }
    }
    
    private final WritableRaster nonICCRasterFilter(Raster raster, WritableRaster compatibleDestRaster) {
        if (this.CSList.length != 2) {
            throw new IllegalArgumentException("Destination ColorSpace is undefined");
        }
        if (raster.getNumBands() != this.CSList[0].getNumComponents()) {
            throw new IllegalArgumentException("Numbers of source Raster bands and source color space components do not match");
        }
        if (compatibleDestRaster == null) {
            compatibleDestRaster = this.createCompatibleDestRaster(raster);
        }
        else {
            if (raster.getHeight() != compatibleDestRaster.getHeight() || raster.getWidth() != compatibleDestRaster.getWidth()) {
                throw new IllegalArgumentException("Width or height of Rasters do not match");
            }
            if (compatibleDestRaster.getNumBands() != this.CSList[1].getNumComponents()) {
                throw new IllegalArgumentException("Numbers of destination Raster bands and destination color space components do not match");
            }
        }
        if (this.srcMinVals == null) {
            this.getMinMaxValsFromColorSpaces(this.CSList[0], this.CSList[1]);
        }
        SampleModel sampleModel = raster.getSampleModel();
        SampleModel sampleModel2 = compatibleDestRaster.getSampleModel();
        int transferType = raster.getTransferType();
        int transferType2 = compatibleDestRaster.getTransferType();
        int n = transferType == 4 || transferType == 5;
        int n2 = transferType2 == 4 || transferType2 == 5;
        int width = raster.getWidth();
        int height = raster.getHeight();
        int numBands = raster.getNumBands();
        int numBands2 = compatibleDestRaster.getNumBands();
        float[] array = null;
        float[] array2 = null;
        if (n == 0) {
            array = new float[numBands];
            for (int i = 0; i < numBands; ++i) {
                if (transferType == 2) {
                    array[i] = (this.srcMaxVals[i] - this.srcMinVals[i]) / 32767.0f;
                }
                else {
                    array[i] = (this.srcMaxVals[i] - this.srcMinVals[i]) / (float)((1 << sampleModel.getSampleSize(i)) - 1);
                }
            }
        }
        if (n2 == 0) {
            array2 = new float[numBands2];
            for (int j = 0; j < numBands2; ++j) {
                if (transferType2 == 2) {
                    array2[j] = 32767.0f / (this.dstMaxVals[j] - this.dstMinVals[j]);
                }
                else {
                    array2[j] = (float)((1 << sampleModel2.getSampleSize(j)) - 1) / (this.dstMaxVals[j] - this.dstMinVals[j]);
                }
            }
        }
        int minY = raster.getMinY();
        int minY2 = compatibleDestRaster.getMinY();
        float[] array3 = new float[numBands];
        ColorSpace colorSpace = this.CSList[0];
        ColorSpace colorSpace2 = this.CSList[1];
        for (int k = 0; k < height; ++k, ++minY, ++minY2) {
            for (int minX = raster.getMinX(), minX2 = compatibleDestRaster.getMinX(), l = 0; l < width; ++l, ++minX, ++minX2) {
                float sampleFloat;
                for (int n3 = 0; n3 < numBands; array3[n3] = sampleFloat, ++n3) {
                    sampleFloat = raster.getSampleFloat(minX, minY, n3);
                    if (n == 0) {
                        sampleFloat = sampleFloat * array[n3] + this.srcMinVals[n3];
                    }
                }
                float[] fromCIEXYZ = colorSpace2.fromCIEXYZ(colorSpace.toCIEXYZ(array3));
                for (int n4 = 0; n4 < numBands2; ++n4) {
                    float n5 = fromCIEXYZ[n4];
                    if (n2 == 0) {
                        n5 = (n5 - this.dstMinVals[n4]) * array2[n4];
                    }
                    compatibleDestRaster.setSample(minX2, minY2, n4, n5);
                }
            }
        }
        return compatibleDestRaster;
    }
    
    private void getMinMaxValsFromProfiles(ICC_Profile icc_Profile, ICC_Profile icc_Profile2) {
        int colorSpaceType = icc_Profile.getColorSpaceType();
        int numComponents = icc_Profile.getNumComponents();
        this.srcMinVals = new float[numComponents];
        this.srcMaxVals = new float[numComponents];
        this.setMinMax(colorSpaceType, numComponents, this.srcMinVals, this.srcMaxVals);
        int colorSpaceType2 = icc_Profile2.getColorSpaceType();
        int numComponents2 = icc_Profile2.getNumComponents();
        this.dstMinVals = new float[numComponents2];
        this.dstMaxVals = new float[numComponents2];
        this.setMinMax(colorSpaceType2, numComponents2, this.dstMinVals, this.dstMaxVals);
    }
    
    private void setMinMax(int n, int n2, float[] array, float[] array2) {
        if (n == 1) {
            array[0] = 0.0f;
            array2[0] = 100.0f;
            array[1] = -128.0f;
            array2[1] = 127.0f;
            array[2] = -128.0f;
            array2[2] = 127.0f;
        }
        else if (n == 0) {
            int n3 = 0;
            int n4 = 1;
            int n5 = 2;
            float n6 = 0.0f;
            array[n5] = n6;
            array[n3] = (array[n4] = n6);
            int n7 = 0;
            int n8 = 1;
            int n9 = 2;
            float n10 = 1.9999695f;
            array2[n9] = n10;
            array2[n7] = (array2[n8] = n10);
        }
        else {
            for (int i = 0; i < n2; ++i) {
                array[i] = 0.0f;
                array2[i] = 1.0f;
            }
        }
    }
    
    private void getMinMaxValsFromColorSpaces(ColorSpace colorSpace, ColorSpace colorSpace2) {
        int numComponents = colorSpace.getNumComponents();
        this.srcMinVals = new float[numComponents];
        this.srcMaxVals = new float[numComponents];
        for (int i = 0; i < numComponents; ++i) {
            this.srcMinVals[i] = colorSpace.getMinValue(i);
            this.srcMaxVals[i] = colorSpace.getMaxValue(i);
        }
        int numComponents2 = colorSpace2.getNumComponents();
        this.dstMinVals = new float[numComponents2];
        this.dstMaxVals = new float[numComponents2];
        for (int j = 0; j < numComponents2; ++j) {
            this.dstMinVals[j] = colorSpace2.getMinValue(j);
            this.dstMaxVals[j] = colorSpace2.getMaxValue(j);
        }
    }
    
    static {
        if (ProfileDeferralMgr.deferring) {
            ProfileDeferralMgr.activateProfiles();
        }
    }
}
